;; Generated package description from helm-core.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "helm-core" "4.0.7.0.20260528.14" "Development files for Helm" '((emacs "25.1") (async "1.9.9")) :commit "662cfc6bd3428675e687647aa898924c3fcdd8ad" :authors '(("Thierry Volpiatto" . "thievol@posteo.net")) :maintainer '("Thierry Volpiatto" . "thievol@posteo.net") :url "https://emacs-helm.github.io/helm/")
